package com.yuanta.smartnet.sample;

import android.Manifest;
import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.Color;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.ViewGroup.LayoutParams;
import android.widget.Toast;

import com.yuanta.smartnet.intrf.ISmartNetInitListener;
import com.yuanta.smartnet.intrf.ISmartNetLoginListener;
import com.yuanta.smartnet.proc.SmartNetMng;
import com.yuanta.smartnet.sample.view.SampleDataView;
import com.yuanta.smartnet.sample.view.SampleHomeView;
import com.yuanta.smartnet.sample.view.SampleIntroView;
import com.yuanta.smartnet.sample.view.SampleLoginView;
import com.yuanta.smartnet.sample.view.util.PermissionChecks;

import java.util.ArrayList;

@SuppressLint("NewApi")
public class SampleActivity
extends Activity
implements ISmartNetInitListener, ISmartNetLoginListener
{
	private final String TAG = getClass().getName();
	public static SampleActivity ms_instance = null;
	private SampleFrameView	m_viewFrame = null;

	private final long FINISH_INTERVAL_TIME = 2000;
	private long backPressedTime = 0;

	private SampleIntroView	m_viewIntro = null;
	private SampleLoginView	m_viewLogin = null;
	private SampleDataView m_viewData = null;
	private SampleHomeView m_viewHome = null;

	public boolean isM_isEnableBackProcess() {
		return m_isEnableBackProcess;
	}

	public void setM_isEnableBackProcess(boolean m_isEnableBackProcess) {
		this.m_isEnableBackProcess = m_isEnableBackProcess;
	}

	private boolean m_isEnableBackProcess = false;

	String[] YUANTA_PERMISSION = { Manifest.permission.READ_EXTERNAL_STORAGE, Manifest.permission.WRITE_EXTERNAL_STORAGE, Manifest.permission.READ_PHONE_STATE };
	String m_strUserID;
	
	ArrayList<String> m_arrAccount = null;				//계좌리스트
	ArrayList<String> m_arrAccountName = null;		//계좌명 리스트
	ArrayList<String> m_arrAccountCode = null;		//상품코드 리스트

	public SampleActivity()
	{
		ms_instance = this;
		m_isEnableBackProcess = false;
	}
	public static SampleActivity getInstance()
	{
		return ms_instance;
	}
	
	/* Called when the activity is first created. */
	@Override
	public void onCreate( Bundle savedInstanceState )
	{
		super.onCreate( savedInstanceState );

		m_arrAccount = new ArrayList<String>();
		m_arrAccountName = new ArrayList<String>();
		m_arrAccountCode = new ArrayList<String>();
		
		m_viewFrame = new SampleFrameView(this);
		m_viewFrame.setLayoutParams( new LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.MATCH_PARENT ) );
		m_viewFrame.setBackgroundColor( Color.rgb( 0, 0, 0 ) );
		
		showIntroView();
		
		setContentView(m_viewFrame);

		//권한 체크

		PermissionChecks checker = new PermissionChecks(this);

		if (checker.lacksPermissions(YUANTA_PERMISSION)) {
			Toast.makeText(this, "권한 설정을 해주세요", Toast.LENGTH_SHORT).show();
			requestPermissions();

		}else{
			initSmartNetMng();
		}
	}

	private void initSmartNetMng()
	{
		// 초기화
		// SmartNetMng는 하나의 Activity에서만 정상 동작합니다. 여러 Activity에서 동시에 초기화하여 사용하지 마십시요.
		SmartNetMng.initSmartNet(this);

		//Listener 셋팅
		SmartNetMng.getInstance().setInitListener(this);
		SmartNetMng.getInstance().setLoginListener(this);
		//TODO: 업체 사용자의 경우 유안타로 부터 받은 값을 세팅 하세요.
//		SmartNetMng.getInstance().setOpenApiCompanyCode('');
	}

	public void requestPermissions()
	{
		String[] arrPermission = new String[3];
		for( int i = 0; i < 3; i++ )
		{
			arrPermission[i] = YUANTA_PERMISSION[i];
		}

		this.requestPermissions(arrPermission, 1234);
	}

	@Override
	public void onRequestPermissionsResult(int requestCode, String permissions[], int[] grantResults)
	{
		switch (requestCode) {
			case 1234: {
				// If request is cancelled, the result arrays are empty.
				if (grantResults.length > 0
						&& grantResults[0] == PackageManager.PERMISSION_GRANTED) {

					// permission was granted, yay!
					initSmartNetMng();

				} else {

					// permission denied, boo! Disable the
					// functionality that depends on this permission.
				}
				return;
			}

			// other 'case' lines to check for other
			// permissions this app might request
		}
	}


	
	@Override
	public void onDestroy()
	{
		super.onDestroy();
		
		if(m_viewFrame != null)
		{
			m_viewFrame.releaseView();
			m_viewFrame = null;
		}

		if(m_viewLogin != null)
		{
			m_viewLogin.releaseView();
			m_viewLogin = null;
		}
	
		if(m_viewData != null)
		{
			m_viewData.releaseView();
			m_viewData = null;
		}
/*
		if(m_viewHome!= null)
		{
			m_viewHome.releaseView();
			m_viewHome = null;
		}*/

		if(m_arrAccount != null)
		{
			m_arrAccount.clear();
			m_arrAccount = null;
		}
		
		if(m_arrAccountName != null)	
		{
			m_arrAccountName.clear();
			m_arrAccountName = null;
		}
	
		if(m_arrAccountName != null)	
		{		
			m_arrAccountCode.clear();
			m_arrAccountCode = null;
		}


		ms_instance = null;
		/**
		 * SmartNet 종료...
		 */
		SmartNetMng.releaseSmartNet();
	}

	@Override
	public void onSessionConnecting() {
		// TODO Auto-generated method stub
		Toast.makeText(this, "서버 접속 시작.", Toast.LENGTH_SHORT ).show();
	}

	@Override
	public void onSessionConnected(boolean isSuccess, String strErrorMsg) {
		// TODO Auto-generated method stub
		//서버 성공
		if(isSuccess == true)
		{
			Toast.makeText(this, strErrorMsg, Toast.LENGTH_SHORT ).show();
		}
		else//서버 실패
		{
			Toast.makeText(this, strErrorMsg, Toast.LENGTH_SHORT ).show();
		}
	}

	// 서버 재접속까지 실패시 호출됨
	@Override
	public void onSessionReconnectFail(String strSessionName, String strErrorMsg) {
		if ("EXECSVR".equals(strSessionName)) {
			Log.e(TAG, "서버 메인 연결 재접속 실패");
		}
		else if ("AUTOSVR".equals(strSessionName)) {
			Log.e(TAG, "서버 AUTO 연결 재접속 실패");
		}
	}

	@Override
	public void onAppVersionState(boolean isDone) {
		// TODO Auto-generated method stub
		Toast.makeText(this, "라이브러리 버젼체크 완료.", Toast.LENGTH_SHORT ).show();
	}
		
	@Override
	public void onMasterDownState(boolean isDone) {
		// TODO Auto-generated method stub
		Toast.makeText(this, "Master 파일 DownLoad...", Toast.LENGTH_SHORT ).show();
	}

	@Override
	public void onMasterLoadState(boolean isDone) {
		// TODO Auto-generated method stub
		Toast.makeText(this, "Master 파일 Loading...", Toast.LENGTH_SHORT ).show();
	}
	
	@Override
	public void onInitFinished()
	{
		/**
		 * 로그인View를 생성 하고 클릭 이벤트 지정
		 */
		showLoginView();
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data)
	{
		super.onActivityResult(requestCode, resultCode, data);
	}

	@Override
	public void onRequiredRefresh()
	{
		Toast.makeText( getBaseContext(), "재접속 되었습니다.", Toast.LENGTH_SHORT ).show();
		if (m_viewData != null) {
			m_viewData.refresh();
		}
	}

	@Override
	public void onLoginStarted()
	{
		if(m_viewFrame != null)
			m_viewFrame.showProgress("로그인 중 입니다.");
	}
	
	@Override
	public void onLoginResult(boolean isSuccess, String strErrorMsg)
	{
		if(m_viewFrame != null)
			m_viewFrame.hideProgress();
		
		if(isSuccess == true )
		{
			Toast.makeText( getBaseContext(), "로그인 성공", Toast.LENGTH_SHORT ).show();
			
			m_strUserID = m_viewLogin.getUserId();
			
			//showDataView();
			showHomeView();
			
		} else {
			Toast.makeText( getBaseContext(), strErrorMsg, Toast.LENGTH_SHORT ).show();
		}
	}

	public void showIntroView()
	{
		if(m_viewIntro != null)
		{
			m_viewIntro.releaseView();
			m_viewIntro = null;
		}

		m_viewIntro = new SampleIntroView(this);
		m_viewIntro.initView();
		
		m_viewIntro.setBackgroundColor(Color.rgb(255, 255, 255));
		
		m_viewFrame.setView(m_viewIntro);
	}
	
	public void showLoginView()
	{
		if(m_viewLogin != null)
		{
			m_viewLogin.releaseView();
			m_viewLogin = null;
		}
		
		m_viewLogin = new SampleLoginView(this);
		m_viewLogin.initView();
		m_viewLogin.setActivity(this);
			
		m_viewLogin.setBackgroundColor( Color.rgb( 255, 255, 255 ) );
		
		m_viewFrame.setView(m_viewLogin);
	}
	public void showHomeView(){
		if(m_viewHome != null)
		{
			m_viewHome.releaseView();
			m_viewHome = null;
		}

		m_viewHome = new SampleHomeView(this);
		m_viewHome.initView(this);

//		//계좌리스트
//		int nCount = SmartNetMng.getInstance().getAccountSize();
//		if(nCount >0)
//		{
//			String strAcc = "";
//			String strAccName = "";
//			String strAccCode ="";
//			for(int i = 0; i <nCount ; i++)
//			{
//				strAcc = SmartNetMng.getInstance().getAccountNo(i);				//계좌번호
//				strAccName = SmartNetMng.getInstance().getAccountName(i);		//계좌명
//				//strAccCode = SmartNetMng.getInstance().GetAccountCode(i);		//상품코드
//				if(strAccCode.contains("01"))	//위탁계좌
//				{
//					m_arrAccount.add(strAcc);
//					m_arrAccountName.add(strAccName);
//					m_arrAccountCode.add(strAccCode);
//				}
//			}
//			if(m_arrAccount.size() > 0)
//			{
//				m_viewData.SetAccount(m_arrAccount.get(0));					//계좌번호
//				m_viewData.SetAccountCode(m_arrAccountCode.get(0));		//계좌 상품코드
//
//				//SmartNetMng.getInstance().setCurrAccountInfo(m_arrAccount.get(0),m_arrAccountCode.get(0));
//			}
//		}

		m_viewFrame.setView(m_viewHome);
	}

	public void showDataView()
	{
		if(m_viewData != null)
		{
			m_viewData.releaseView();
			m_viewData = null;
		}	

		m_viewData = new SampleDataView(this);
		m_viewData.initView(this);

//		//계좌리스트 
//		int nCount = SmartNetMng.getInstance().getAccountSize();
//		if(nCount >0)
//		{
//			String strAcc = "";
//			String strAccName = "";
//			String strAccCode ="";
//			for(int i = 0; i <nCount ; i++)
//			{
//				strAcc = SmartNetMng.getInstance().getAccountNo(i);				//계좌번호
//				strAccName = SmartNetMng.getInstance().getAccountName(i);		//계좌명
//				//strAccCode = SmartNetMng.getInstance().GetAccountCode(i);		//상품코드
//				if(strAccCode.contains("01"))	//위탁계좌
//				{
//					m_arrAccount.add(strAcc);
//					m_arrAccountName.add(strAccName);
//					m_arrAccountCode.add(strAccCode);
//				}
//			}		
//			if(m_arrAccount.size() > 0)
//			{
//				m_viewData.SetAccount(m_arrAccount.get(0));					//계좌번호
//				m_viewData.SetAccountCode(m_arrAccountCode.get(0));		//계좌 상품코드
//				
//				//SmartNetMng.getInstance().setCurrAccountInfo(m_arrAccount.get(0),m_arrAccountCode.get(0));
//			}
//		}

		m_viewFrame.setView(m_viewData);
	}
	/*
	public void showHomeView()
	{
		if(m_viewHome != null)
		{
			m_viewHome.releaseView();
			m_viewHome = null;
		}

		m_viewHome = new SampleHomeView(this);
		m_viewHome.initView(this);


		m_viewFrame.setView(m_viewHome);
	}
	*/
	public void sendMessage(int nMsg, int nArg1, int nArg2)
	{
		if(m_handlerProc == null) return;

		Message msg = m_handlerProc.obtainMessage(nMsg, nArg1, nArg2);
		m_handlerProc.sendMessage(msg);
	}
	
	private final Handler m_handlerProc = new Handler()
	{
		@Override
		public void handleMessage(Message message)
		{
			switch(message.what)
			{
				case 0:				// ViewData
					showDataView();
					break;
					
			}
		}
	};

	@Override
	public void onBackPressed() {
		if (m_isEnableBackProcess == false) {

			long tempTime = System.currentTimeMillis();
			long intervalTime = tempTime - backPressedTime;

			if (0 <= intervalTime && FINISH_INTERVAL_TIME >= intervalTime) {
				super.onBackPressed();
			} else {
				backPressedTime = tempTime;
				Toast.makeText(this, "Back 버튼을 한번 더 누르시면 앱이 종료됩니다.", Toast.LENGTH_SHORT).show();
			}
		}
		else {
			showHomeView();
		}
	}



}
