package com.yuanta.smartnet.sample.view;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.os.Build;
import android.text.InputType;
import android.util.Log;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.inputmethod.EditorInfo;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.ScrollView;
import android.widget.TextView;
import android.widget.Toast;

import com.itgen.corelib.util.TRACE;
import com.yuanta.smartnet.intrf.IRealDataListener;
import com.yuanta.smartnet.intrf.ISmartNetAccountPwdCheckListener;
import com.yuanta.smartnet.intrf.ITranDataListener;
import com.yuanta.smartnet.proc.SmartNetMng;
import com.yuanta.smartnet.proc.SmartNetRealProc;
import com.yuanta.smartnet.proc.SmartNetTranProc;
import com.yuanta.smartnet.sample.SampleActivity;
import com.yuanta.smartnet.sample.view.sise.ItemHogaView;
import com.yuanta.smartnet.sample.view.sise.ItemPriceView;
import com.yuanta.smartnet.sample.view.sub.AccountSelectSpinner;
import com.yuanta.smartnet.sample.view.sub.ItemCodeSpinner;
import com.yuanta.smartnet.sample.view.util.SampleUtil;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.Locale;

public class SampleDataView
extends SampleBaseView
implements ITranDataListener, IRealDataListener, View.OnClickListener
{
	private static final String LOG_TAG = "종목 데이터";

	public interface ID
    {
        int     CTRL_ID_BUY = 100;
        int     CTRL_ID_SELL = 101;
        int		CTRL_ID_MODIFY = 102;
        int		CTRL_ID_CANCEL = 103;
        int		CTRL_ID_NEXT = 104;

		int		CTRL_ID_REFRESH = 105;
    }
	
	// 화면 표시 뷰
	private EditText			m_editItemCode;						// 종목코드
	private ItemCodeSpinner		m_spinnerItemCode;					// 종목 선택
	
	private ItemPriceView		m_viewItemPrice;					// 종목 현재가 정보
	private ItemHogaView		m_viewItemHoga;						// 종목 호가 (5호가)
	
	private AccountSelectSpinner	m_spinnerAccount;				// 계좌 선택
	private EditText				m_editAccountPwd;				// 계좌 비번
	
	private EditText			m_editTradeCount;					// 거래수량
	private EditText			m_editTradeUnitPrice;				// 거래단가
	private EditText			m_editTradeNo;						// 주문번호

	private ListView			m_listView;
	private DailyPriceAdapter   m_adapterDailyPrice;
	private ArrayList<ListItem> m_arrListData = new ArrayList<>();
	private Button				m_btnNext;
	private Button				m_btnRefresh;


	private ListView			m_balancelistView;
	private StockBalanceAdapter   m_adapterStockBalance;
	private ArrayList<BalanceListItem> m_arrBalanceListData = new ArrayList<>();
	
	// 데이터 처리
	private SmartNetTranProc	m_tranCurrPrice = null;				// 주식 현재가 조회
	private SmartNetTranProc	m_tranCurrHoga = null;				// 주식 호가 조회

	private SmartNetRealProc	m_realCurrPrice = null;				// 주식 체결 실시간
	private SmartNetRealProc	m_realCurrHoga = null;				// 주식 호가 실시간
	private SmartNetRealProc	m_realStockChegyul = null;			// 주식 체결 실시간
	private SmartNetRealProc	m_realAccountChange = null;			// 잔고 변경 실시간
	
	private SmartNetTranProc	m_tranStockBuy = null;				// 주식 매수 주문
	private SmartNetTranProc	m_tranStockSell = null;				// 주식 매도 주문
	private SmartNetTranProc	m_tranStockModify = null;			// 정정 주문
	private SmartNetTranProc	m_tranStockCancel = null;			// 취소 주문

	private SmartNetTranProc	m_tranDailyPrice = null;			// 일자별 주가
	private SmartNetTranProc	m_tranStockBalance = null;			// 보유잔고
	// 메인
	private SampleActivity		m_actMain = null;

	// 레이아웃 구성
	private int					TITLE_WIDTH = 100;
	private int					INPUT_WIDTH = 200;
	private int					PADDING_H = 10;
	private int					PADDING_V = 10;

	private Context				m_context;

	private static final String INBLOCK = "InBlock";
	private static final String OUTBLOCK = "OutBlock";
	
	public SampleDataView(Context context)
	{
		super(context);
		m_context = context;
	
		setBackgroundColor(Color.WHITE);

		SmartNetMng.getInstance().setFieldLogEnable(true);
		
		TITLE_WIDTH = (int)SampleUtil.dipToPixels(context, 80);
		INPUT_WIDTH = (int)SampleUtil.dipToPixels(context, 200);
		PADDING_H = (int)SampleUtil.dipToPixels(context, 10);
		PADDING_V = (int)SampleUtil.dipToPixels(context, 10);
		
		// TR 초기화
		m_tranCurrPrice = new SmartNetTranProc(context);
		m_tranCurrPrice.initInstance(this);
		m_tranCurrPrice.setQueryFile("DSO300001");
		m_tranCurrPrice.setTranId("주식현재가");
		
		m_tranCurrHoga = new SmartNetTranProc(context);
		m_tranCurrHoga.initInstance(this);
		m_tranCurrHoga.setQueryFile("DSO300002");
		m_tranCurrHoga.setTranId("주식호가");
		
		// 주문 TR 초기화
		m_tranStockBuy = new SmartNetTranProc(context);
		m_tranStockBuy.initInstance(this);
		m_tranStockBuy.setQueryFile("DSO100001");
		m_tranStockBuy.setTranId("주식매수주문");
		m_tranStockBuy.setCertType(1);
		
		m_tranStockSell = new SmartNetTranProc(context);
		m_tranStockSell.initInstance(this);
		m_tranStockSell.setQueryFile("DSO100002");
		m_tranStockSell.setTranId("주식매도주문");
		m_tranStockSell.setCertType(1);
		
		m_tranStockModify = new SmartNetTranProc(context);
		m_tranStockModify.initInstance(this);
		m_tranStockModify.setQueryFile("DSO100003");
		m_tranStockModify.setTranId("주식정정주문");
		m_tranStockModify.setCertType(1);

		m_tranStockCancel = new SmartNetTranProc(context);
		m_tranStockCancel.initInstance(this);
		m_tranStockCancel.setQueryFile("DSO100004");
		m_tranStockCancel.setTranId("주식주문취소");
		m_tranStockCancel.setCertType(1);

		// 다음조회예제
		m_tranDailyPrice = new SmartNetTranProc(context);
		m_tranDailyPrice.initInstance(this);
		m_tranDailyPrice.setQueryFile("DSO401001");
		m_tranDailyPrice.setNextFieldInfo(2, 0); // 다음 조회 여부를 판단할 아웃풋 변수의 블럭과 해당 블럭에서의 위치(일반적으로 next변수의 위치)
		m_tranDailyPrice.setTranId("일별주가");

		// 보유잔고 예제
		m_tranStockBalance = new SmartNetTranProc(context);
		m_tranStockBalance.initInstance(this);
		m_tranStockBalance.setQueryFile("DSO202021");
		m_tranStockBalance.setTranId("보유잔고");

		// 실시간 초기화
		m_realCurrPrice = new SmartNetRealProc(context);
		m_realCurrPrice.initInstance(this);
		m_realCurrPrice.setQueryFile("AUTO11");
		m_realCurrPrice.setRealId("주식현재가실시간");
		
		m_realCurrHoga = new SmartNetRealProc(context);
		m_realCurrHoga.initInstance(this);
		m_realCurrHoga.setQueryFile("AUTO12");
		m_realCurrHoga.setRealId("주식호가실시간");

		m_realStockChegyul = new SmartNetRealProc(context);
		m_realStockChegyul.initInstance(this);
		m_realStockChegyul.setQueryFile("AUTO70");
		m_realStockChegyul.setRealId("주식체결실시간");

		m_realAccountChange = new SmartNetRealProc(context);
		m_realAccountChange.initInstance(this);
		m_realAccountChange.setQueryFile("AUTO74");
		m_realAccountChange.setRealId("잔고변경실시간");

	}
	
	//화면 초기화
	public void initView( SampleActivity	actMain)
	{	
		m_actMain = actMain;
		
		ScrollView viewScroll = new ScrollView(getContext());

		LinearLayout layoutFrame = new LinearLayout(getContext());
		layoutFrame.setOrientation(LinearLayout.VERTICAL);
		
		LinearLayout layoutItemCode = makeItemCodeInput();
		layoutFrame.addView(layoutItemCode, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
		
		m_viewItemPrice = new ItemPriceView(getContext());
		m_viewItemPrice.setPadding(PADDING_H, 0, PADDING_H, 0);
		layoutFrame.addView(m_viewItemPrice, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(getContext(), 70)));
		
		m_viewItemHoga = new ItemHogaView(getContext());
		m_viewItemHoga.setOnHogaViewListener(new ItemHogaView.OnHogaViewListener()
		{
			@Override
			public void onHogaClicked(String strPrice)
			{
				if(m_editTradeUnitPrice != null)
					m_editTradeUnitPrice.setText(strPrice);
			}
		});
		layoutFrame.addView(m_viewItemHoga, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(getContext(), 35 * 10)));
		
		LinearLayout layoutAccount = makeAccountInput();
		layoutFrame.addView(layoutAccount, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
		
		LinearLayout layoutTrade = makeTradeInput();
		layoutFrame.addView(layoutTrade, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));

		// 보유잔고
		LinearLayout layoutBalance = makeBalanceView();
		layoutFrame.addView(layoutBalance, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));

		// 일자별주가
		LinearLayout layoutDailyPrice = makeDailyPriceView();
		layoutFrame.addView(layoutDailyPrice, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));


		viewScroll.addView(layoutFrame, new LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
		addView(viewScroll, new LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.MATCH_PARENT));



	}

	public void releaseView()
	{
		removeAllViews();

		if(m_tranCurrPrice != null)
		{
			m_tranCurrPrice.clearInstance();
			m_tranCurrPrice = null;
		}

		if(m_tranCurrHoga != null)
		{
			m_tranCurrHoga.clearInstance();
			m_tranCurrHoga = null;
		}

		if(m_tranStockBuy != null)
		{
			m_tranStockBuy.clearInstance();
			m_tranStockBuy = null;
		}

		if(m_tranStockSell != null)
		{
			m_tranStockSell.clearInstance();
			m_tranStockSell = null;
		}

		if(m_tranStockModify != null)
		{
			m_tranStockModify.clearInstance();
			m_tranStockModify = null;
		}

		if(m_tranStockCancel != null)
		{
			m_tranStockCancel.clearInstance();
			m_tranStockCancel = null;
		}

		if(m_realCurrPrice != null)
		{
			m_realCurrPrice.clearInstance();
			m_realCurrPrice = null;
		}

		if(m_realCurrHoga != null)
		{
			m_realCurrHoga.clearInstance();
			m_realCurrHoga = null;
		}

		if(m_realStockChegyul != null)
		{
			m_realStockChegyul.clearInstance();
			m_realStockChegyul = null;
		}

		if(m_realAccountChange != null)
		{
			m_realAccountChange.clearInstance();
			m_realAccountChange = null;
		}

		if(m_tranStockBalance != null)
		{
			m_tranStockBalance.clearInstance();
			m_tranStockBalance = null;
		}



	}

	public void refresh()
	{
		requestCurrPrice();
		requesetDailyPrice();
		RequestStockChegyulReal();
		RequestAccountChangeReal();

		if( m_editAccountPwd != null && m_editAccountPwd.getText().toString() != "" ) {

			requestStockBalance();
		}

	}
	
	private LinearLayout makeItemCodeInput()
	{
		// 종목코드
		TextView textCode = makeTextView("종목코드");
		m_editItemCode = makeEditView("");
		m_editItemCode.setInputType(InputType.TYPE_CLASS_NUMBER);
		m_editItemCode.setOnEditorActionListener(new TextView.OnEditorActionListener()
		{
			@Override
			public boolean onEditorAction(TextView view, int actionId, KeyEvent event)
			{
				if(actionId == EditorInfo.IME_ACTION_DONE || actionId == EditorInfo.IME_ACTION_NEXT)
				{
					if(m_spinnerItemCode != null)
					{
						m_spinnerItemCode.setItemCode(view.getText().toString());
					}
					
					if(actionId == EditorInfo.IME_ACTION_NEXT)
					{
						if(m_editAccountPwd != null) m_editAccountPwd.requestFocus();
					}
					
					return true;
				}
				
				return false;
			}
			
		});
		m_spinnerItemCode = new ItemCodeSpinner(getContext());
		m_spinnerItemCode.setItemList(SmartNetMng.getInstance().getSortedStockCodeList());
		//m_spinnerItemCode.setItemList(SmartNetMng.getInstance().getSortedUSAStockCodeList());

		m_spinnerItemCode.setOnItemCodeSelectedListener(new ItemCodeSpinner.OnItemCodeSelectedListener()
		{
			@Override
			public void onItemSelected(String strCode, String strName, String strMarket)
			{
				m_editItemCode.setText(strCode);

				refresh();
			}
		});
		
		LinearLayout layoutCode = new LinearLayout(getContext());
		layoutCode.setOrientation(LinearLayout.HORIZONTAL);
		
		layoutCode.addView(textCode, new LinearLayout.LayoutParams(TITLE_WIDTH, LayoutParams.MATCH_PARENT));
		layoutCode.addView(m_editItemCode, new LinearLayout.LayoutParams(0, LayoutParams.MATCH_PARENT, 2));
		layoutCode.addView(m_spinnerItemCode, new LinearLayout.LayoutParams(0, LayoutParams.MATCH_PARENT, 3));
		
		layoutCode.setPadding(PADDING_H, PADDING_V, PADDING_H, PADDING_V);
		
		return layoutCode;
	}
	
	private LinearLayout makeAccountInput()
	{
		// 계좌번호
		TextView textCode = makeTextView("보유계좌");

		m_spinnerAccount = new AccountSelectSpinner(getContext());
		
		m_spinnerAccount.resetAccountList();
		
		SmartNetMng mngNet = SmartNetMng.getInstance();
		
		int nAccCount = mngNet.getAccountSize();

		for(int i = 0; i < nAccCount; i++)
		{
			//주식주문 계좌타입
			String tempAcnt = mngNet.getAccountInfo(mngNet.getAccountNo(i), "productcode" );

			for ( String str : getStockAcctType() )
			{
				if (tempAcnt.contains(str))
					m_spinnerAccount.addAccountList(mngNet.getAccountNo(i), mngNet.getAccountName(i));
			}

		}

		m_spinnerAccount.setOnAccountSelectedListener(new AccountSelectSpinner.OnAccountSelectedListener() {
			
			@Override
			public void onAccountSelected(String strNo)
			{
				if(m_editAccountPwd != null)
				{
					m_editAccountPwd.setText("");
					m_editAccountPwd.requestFocus();

				}
			}
		});
		
		m_editAccountPwd = makeEditView("");
		setEditText(m_editAccountPwd, false, true);
		m_editAccountPwd.setOnEditorActionListener(new TextView.OnEditorActionListener()
		{
			@Override
			public boolean onEditorAction(TextView view, int actionId, KeyEvent event)
			{
				if(actionId == EditorInfo.IME_ACTION_DONE || actionId == EditorInfo.IME_ACTION_NEXT)
				{
					SmartNetMng.getInstance().checkAccPwd(m_spinnerAccount.getAccountNo(), m_editAccountPwd.getText().toString(),
							new ISmartNetAccountPwdCheckListener()
					{
						@Override
						public void onAccountPwdCheckResult(boolean isSuccess, String strAccNo, String strMessage)
						{
							if(isSuccess)
							{
								Toast.makeText(m_actMain, "계좌 비밀번호 체크 완료", Toast.LENGTH_LONG).show();
								requestStockBalance();
							} else {
								Toast.makeText(m_actMain, strMessage, Toast.LENGTH_LONG).show();
								m_editAccountPwd.setText("");
							}
						}
					});
					
					return true;
				}
				
				return false;
			}
			
		});
		
		LinearLayout layoutAccount = new LinearLayout(getContext());
		layoutAccount.setOrientation(LinearLayout.HORIZONTAL);
		layoutAccount.setBackgroundColor(Color.LTGRAY);
		
		layoutAccount.addView(textCode, new LinearLayout.LayoutParams(TITLE_WIDTH, LayoutParams.MATCH_PARENT));
		layoutAccount.addView(m_spinnerAccount, new LinearLayout.LayoutParams(0, LayoutParams.MATCH_PARENT, 5));
		layoutAccount.addView(m_editAccountPwd, new LinearLayout.LayoutParams(0, LayoutParams.MATCH_PARENT, 2));
		
		layoutAccount.setPadding(PADDING_H, PADDING_V, PADDING_H, PADDING_V);
		
		return layoutAccount;
	}
	
	public LinearLayout makeTradeInput()
	{
		// 1. 컨트롤 생성
		
		// 1.1. 거래단가
		TextView textPrice = makeTextView("단가");
		m_editTradeUnitPrice = makeEditView("");
		m_editTradeUnitPrice.setInputType(InputType.TYPE_CLASS_NUMBER);

		// 1.2. 거래수량
		TextView textCount = makeTextView("수량");
		m_editTradeCount = makeEditView("");
		m_editTradeCount.setInputType(InputType.TYPE_CLASS_NUMBER);
		
		// 1.3. 주문번호
		TextView textNo = makeTextView("주문번호");
		m_editTradeNo = makeEditView("");
		m_editTradeNo.setInputType(InputType.TYPE_CLASS_NUMBER);
		
		// 1.4. 주문버튼
		Button buttonBuy = makeCtrlButton(ID.CTRL_ID_BUY, "매수");
		buttonBuy.setOnClickListener(this);
		Button buttonSell = makeCtrlButton(ID.CTRL_ID_SELL, "매도");
		buttonSell.setOnClickListener(this);
		Button buttonModify = makeCtrlButton(ID.CTRL_ID_MODIFY, "정정");
		buttonModify.setOnClickListener(this);
		Button buttonCancel = makeCtrlButton(ID.CTRL_ID_CANCEL, "취소");
		buttonCancel.setOnClickListener(this);
		
		// 2. 레이아웃 구성
		LinearLayout layoutTrade = new LinearLayout(getContext());
		layoutTrade.setOrientation(LinearLayout.VERTICAL);
		
		// 2.1. 입력라인
		LinearLayout layoutLine1 = new LinearLayout(getContext());
		layoutLine1.setOrientation(LinearLayout.HORIZONTAL);
		
		layoutLine1.addView(textPrice, new LinearLayout.LayoutParams(TITLE_WIDTH, LayoutParams.MATCH_PARENT));
		layoutLine1.addView(m_editTradeUnitPrice, new LinearLayout.LayoutParams(INPUT_WIDTH, LayoutParams.MATCH_PARENT));

		LinearLayout layoutLine2 = new LinearLayout(getContext());
		layoutLine2.setOrientation(LinearLayout.HORIZONTAL);

		layoutLine2.addView(textCount, new LinearLayout.LayoutParams(TITLE_WIDTH, LayoutParams.MATCH_PARENT));
		layoutLine2.addView(m_editTradeCount, new LinearLayout.LayoutParams(INPUT_WIDTH, LayoutParams.MATCH_PARENT));

		LinearLayout layoutLine3 = new LinearLayout(getContext());
		layoutLine3.setOrientation(LinearLayout.HORIZONTAL);

		layoutLine3.addView(textNo, new LinearLayout.LayoutParams(TITLE_WIDTH, LayoutParams.MATCH_PARENT));
		layoutLine3.addView(m_editTradeNo, new LinearLayout.LayoutParams(INPUT_WIDTH, LayoutParams.MATCH_PARENT));

		// 2.2. 버튼 라인
		LinearLayout layoutLine4 = new LinearLayout(getContext());
		layoutLine4.setOrientation(LinearLayout.HORIZONTAL);
		layoutLine4.setPadding(0, PADDING_V, 0, 0);
		
		layoutLine4.addView(buttonBuy, new LinearLayout.LayoutParams(0, LayoutParams.WRAP_CONTENT, 1));
		layoutLine4.addView(buttonSell, new LinearLayout.LayoutParams(0, LayoutParams.WRAP_CONTENT, 1));
		layoutLine4.addView(buttonModify, new LinearLayout.LayoutParams(0, LayoutParams.WRAP_CONTENT, 1));
		layoutLine4.addView(buttonCancel, new LinearLayout.LayoutParams(0, LayoutParams.WRAP_CONTENT, 1));
		
		// 3. 구성 완료
		layoutTrade.addView(layoutLine1, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
		layoutTrade.addView(layoutLine2, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
		layoutTrade.addView(layoutLine3, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
		layoutTrade.addView(layoutLine4, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
		
		layoutTrade.setPadding(PADDING_H, PADDING_V, PADDING_H, PADDING_V);
		
		return layoutTrade;
	}

	private LinearLayout makeDailyPriceView()
	{
		TextView textDailyPrice = makeTextView("일자별주가");
		textDailyPrice.setBackgroundColor(Color.LTGRAY);
		textDailyPrice.setPadding(PADDING_H, PADDING_V, PADDING_H, PADDING_V);
		LinearLayout layoutDailyPrice = new LinearLayout(getContext());
		layoutDailyPrice.setOrientation(LinearLayout.VERTICAL);
		layoutDailyPrice.addView(textDailyPrice, new LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(m_context, 50)));

        m_adapterDailyPrice = new DailyPriceAdapter(getContext(), m_arrListData);
		m_listView = new ListView(m_context);
		m_listView.setAdapter(m_adapterDailyPrice);
		if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
			m_listView.setNestedScrollingEnabled(true);
		}
		m_listView.setDivider(new ColorDrawable(Color.GRAY));
		m_listView.setDividerHeight(1);
		m_listView.setFocusable(false);
		LinearLayout.LayoutParams layoutList = new LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(m_context, 300));
		layoutDailyPrice.addView(m_listView, layoutList);

		m_btnNext = makeCtrlButton(ID.CTRL_ID_NEXT, "다음조회");
		m_btnNext.setOnClickListener(this);
		layoutDailyPrice.addView(m_btnNext, new LinearLayout.LayoutParams((int)SampleUtil.dipToPixels(m_context, 150), (int)SampleUtil.dipToPixels(m_context, 50)));

		return layoutDailyPrice;
	}

	private LinearLayout makeBalanceView()
	{
		TextView textBalance = makeTextView("보유잔고(종목명/평균매입가/현재가)");
		textBalance.setBackgroundColor(Color.LTGRAY);
		textBalance.setPadding(PADDING_H, PADDING_V, PADDING_H, PADDING_V);
		LinearLayout layoutBalance = new LinearLayout(getContext());
		layoutBalance.setOrientation(LinearLayout.VERTICAL);
		layoutBalance.addView(textBalance, new LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(m_context, 50)));

		m_adapterStockBalance = new StockBalanceAdapter(getContext(), m_arrBalanceListData);
		m_balancelistView = new ListView(m_context);
		m_balancelistView.setAdapter(m_adapterStockBalance);
		if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
			m_balancelistView.setNestedScrollingEnabled(true);
		}
		m_balancelistView.setDivider(new ColorDrawable(Color.GRAY));
		m_balancelistView.setDividerHeight(1);
		m_balancelistView.setFocusable(false);
		LinearLayout.LayoutParams layoutList = new LinearLayout.LayoutParams(LinearLayout.LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(m_context, 300));
		layoutBalance.addView(m_balancelistView, layoutList);

		return layoutBalance;
	}
	
	//계좌번호 셋팅
	public void SetAccount(String strAccount)
	{
//		EditText view = (EditText)findViewById(CtrlID.CTRL_ID_ACC);
//		if(view != null)
//		{
//			view.setText(strAccount);
//		}
	}

	private void requestCurrPrice()
	{
		// 조회 요청 전에, 실시간 요청을 먼저 클리어 한다
		if(m_realCurrPrice != null) m_realCurrPrice.cancelRealData();
		if(m_realCurrHoga != null) m_realCurrHoga.cancelRealData();
			
		// 현재 지정된 종목으로, 현재가/호가 조회 요청
		if(m_tranCurrPrice != null)
		{
			m_tranCurrPrice.clearInputData();
			m_tranCurrPrice.clearOutputData();
			
			m_tranCurrPrice.setSingleData(INBLOCK+"1", "jang", m_spinnerItemCode.getItemType());
			m_tranCurrPrice.setSingleData(INBLOCK+"1", "jongcode", m_spinnerItemCode.getItemCode());
			
			m_tranCurrPrice.requestData();
		}
		
		if(m_tranCurrHoga != null)
		{
			m_tranCurrHoga.clearInputData();
			m_tranCurrHoga.clearOutputData();
			
			m_tranCurrHoga.setSingleData(INBLOCK+"1", "jang", m_spinnerItemCode.getItemType());
			m_tranCurrHoga.setSingleData(INBLOCK+"1", "jongcode", m_spinnerItemCode.getItemCode());
			
			m_tranCurrHoga.requestData();
		}
	}
	
	private void requestCurrPriceReal()
	{
		if(m_tranCurrPrice == null) return;
		
		String strItemCode = m_tranCurrPrice.getSingleData(INBLOCK+"1", "jongcode").trim();	// 현재가 요청한 종목코드
		
		m_realCurrPrice.setRealData(INBLOCK+"1", "jongcode", strItemCode);
		m_realCurrPrice.requestReal();
	}
	
	private void requestCurrHogaReal()
	{
		if(m_tranCurrHoga == null) return;
		
		String strItemCode = m_tranCurrHoga.getSingleData(INBLOCK+"1", "jongcode").trim();	// 호가 데이터 요청한 종목코드
		
		m_realCurrHoga.setRealData(INBLOCK+"1", "jongcode", strItemCode);
		m_realCurrHoga.requestReal();
	}
	
	// 주식 매수 주문
	private void requestOrderBuy()
	{
		if(m_tranStockBuy == null) return;
		
		String strAccountNo = m_spinnerAccount.getAccountNo();
		String strAccountPwd = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "pwd");
		String strAccountId = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "accountid");
		String strAccountProductCode = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "productcode");
		
		String strItemCode = m_spinnerItemCode.getItemCode();
		String strItemType = m_spinnerItemCode.getItemType();
		
		String strOrderCount = m_editTradeCount.getText().toString();
		String strOrderPrice = m_editTradeUnitPrice.getText().toString();
		
		m_tranStockBuy.clearInputData();
		m_tranStockBuy.clearOutputData();
		
		m_tranStockBuy.setSingleData(INBLOCK+"1", "acnt_aid", strAccountId);					// 계좌식별번호
		m_tranStockBuy.setSingleData(INBLOCK+"1", "gds_acnt_tp", strAccountProductCode);		// 계좌상품구분코드
		m_tranStockBuy.setSingleData(INBLOCK+"1", "passwd", strAccountPwd);					// 계좌비번
		m_tranStockBuy.setSingleData(INBLOCK+"1", "meme_gubun", "01");				// 매매구분
																// 01:보통, 05:시장가, 06:조건부지정가, 12:최유리지정가, 13:최우선지정가, 71:시간외종가, 81:시간외단일가
		
		m_tranStockBuy.setSingleData(INBLOCK+"1", "jong_code", strItemCode);					// 종목코드
		m_tranStockBuy.setSingleData(INBLOCK+"1", "jang_gubun", strItemType);				// 장내장외구분 0:코스피, 1:코스닥, 2:else
		m_tranStockBuy.setSingleData(INBLOCK+"1", "order_cnt", strOrderCount);				// 주문수량
		m_tranStockBuy.setSingleData(INBLOCK+"1", "order_price", strOrderPrice);				// 주문가격
		m_tranStockBuy.setSingleData(INBLOCK+"1", "jumun_condition", "00");			// 주문조건 00:일반, 01:IOC, 02:FOK
		m_tranStockBuy.setSingleData(INBLOCK+"1", "systrd_gubun", "0");				// 시스템트레이딩 0:일반, 1:system trading
		m_tranStockBuy.setSingleData(INBLOCK+"1", "ord_plan_no", "000000");			// 주문계획번호 000000 : default
		
		m_tranStockBuy.requestData();
	}
	
	// 주식 매도 주문
	private void requestOrderSell()
	{
		if(m_tranStockSell == null) return;
		
		String strAccountNo = m_spinnerAccount.getAccountNo();
		String strAccountPwd = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "pwd");
		String strAccountId = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "accountid");
		String strAccountProductCode = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "productcode");
		
		String strItemCode = m_spinnerItemCode.getItemCode();
		String strItemType = m_spinnerItemCode.getItemType();
		
		String strOrderCount = m_editTradeCount.getText().toString();
		String strOrderPrice = m_editTradeUnitPrice.getText().toString();
		
		m_tranStockSell.clearInputData();
		m_tranStockSell.clearOutputData();
		
		m_tranStockSell.setSingleData(INBLOCK+"1", "acnt_aid", strAccountId);				// 계좌식별번호
		m_tranStockSell.setSingleData(INBLOCK+"1", "gds_acnt_tp", strAccountProductCode);	// 계좌상품구분코드
		m_tranStockSell.setSingleData(INBLOCK+"1", "passwd", strAccountPwd);					// 계좌비번
		m_tranStockSell.setSingleData(INBLOCK+"1", "meme_gubun", "01");				// 매매구분
																// 01:보통, 05:시장가, 06:조건부지정가, 12:최유리지정가, 13:최우선지정가, 71:시간외종가, 81:시간외단일가
		
		m_tranStockSell.setSingleData(INBLOCK+"1", "jong_code", strItemCode);				// 종목코드
		m_tranStockSell.setSingleData(INBLOCK+"1", "jang_gubun", strItemType);				// 장내장외구분 0:코스피, 1:코스닥, 2:else
		m_tranStockSell.setSingleData(INBLOCK+"1", "jang_gubun", strOrderCount);				// 주문수량
		m_tranStockSell.setSingleData(INBLOCK+"1", "order_price", strOrderPrice);			// 주문가격
		m_tranStockSell.setSingleData(INBLOCK+"1", "jumun_condition", "00");			// 주문조건 00:일반, 01:IOC, 02:FOK
		m_tranStockSell.setSingleData(INBLOCK+"1", "systrd_gubun", "0");				// 시스템트레이딩 0:일반, 1:system trading
		m_tranStockSell.setSingleData(INBLOCK+"1", "ord_plan_no", "000000");			// 주문계획번호 000000 : default
		
		m_tranStockSell.requestData();
	}
	
	// 주식 정정 주문
	private void requestOrderModify()
	{
		if(m_tranStockModify == null) return;
		
		String strAccountNo = m_spinnerAccount.getAccountNo();
		String strAccountPwd = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "pwd");
		String strAccountId = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "accountid");
		String strAccountProductCode = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "productcode");
		
		String strItemCode = m_spinnerItemCode.getItemCode();
		String strItemType = m_spinnerItemCode.getItemType();
		
		String strOrderCount = m_editTradeCount.getText().toString();
		String strOrderPrice = m_editTradeUnitPrice.getText().toString();
		
		String strOrgOrderNo = m_editTradeNo.getText().toString();
		
		m_tranStockModify.clearInputData();
		m_tranStockModify.clearOutputData();
		
		m_tranStockModify.setSingleData(INBLOCK+"1", "acnt_aid", strAccountId);				// 계좌식별번호
		m_tranStockModify.setSingleData(INBLOCK+"1", "gds_acnt_tp", strAccountProductCode);	// 계좌상품구분코드
		m_tranStockModify.setSingleData(INBLOCK+"1", "passwd", strAccountPwd);				// 계좌비번
		m_tranStockModify.setSingleData(INBLOCK+"1", "org_order_no", strOrgOrderNo);			// 원주문번호
		m_tranStockModify.setSingleData(INBLOCK+"1", "mod_can_gubun", "2");			// 정정/취소 구분 2:전부정정, 1:일부정정
		
		m_tranStockModify.setSingleData(INBLOCK+"1", "jong_code", strItemCode);				// 종목코드
		m_tranStockModify.setSingleData(INBLOCK+"1", "jang_gubun", strItemType);				// 장내장외구분 0:코스피, 1:코스닥, 2:else
		m_tranStockModify.setSingleData(INBLOCK+"1", "order_cnt", strOrderCount);			// 정정수량
		m_tranStockModify.setSingleData(INBLOCK+"1", "order_price", strOrderPrice);			// 주문가격
		m_tranStockModify.setSingleData(INBLOCK+"1", "meme_gubun", "01");			// 매매구분
																	// 01:보통, 05:시장가, 06:조건부지정가, 12:최유리지정가, 13:최우선지정가, 71:시간외종가, 81:시간외단일가
		m_tranStockModify.setSingleData(INBLOCK+"1", "jumun_condition", "00");		// 주문조건 00:일반, 01:IOC, 02:FOK
		
		m_tranStockModify.requestData();
	}
	
	// 주식 취소 주문
	private void requestOrderCancel()
	{
		if(m_tranStockCancel == null) return;
		
		String strAccountNo = m_spinnerAccount.getAccountNo();
		String strAccountPwd = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "pwd");
		String strAccountId = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "accountid");
		String strAccountProductCode = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "productcode");
		
		String strItemCode = m_spinnerItemCode.getItemCode();
		String strItemType = m_spinnerItemCode.getItemType();
		
		String strOrderCount = m_editTradeCount.getText().toString();
		String strOrderPrice = m_editTradeUnitPrice.getText().toString();
		
		String strOrgOrderNo = m_editTradeNo.getText().toString();
		
		m_tranStockCancel.clearInputData();
		m_tranStockCancel.clearOutputData();
		
		m_tranStockCancel.setSingleData(INBLOCK+"1", "acnt_aid", strAccountId);				// 계좌식별번호
		m_tranStockCancel.setSingleData(INBLOCK+"1", "gds_acnt_tp", strAccountProductCode);	// 계좌상품구분코드
		m_tranStockCancel.setSingleData(INBLOCK+"1", "passwd", strAccountPwd);				// 계좌비번
		m_tranStockCancel.setSingleData(INBLOCK+"1", "org_order_no", strOrgOrderNo);			// 원주문번호
		m_tranStockCancel.setSingleData(INBLOCK+"1", "time_gubun", "1");				// 시간구분 1:장중, 2:시간외
		m_tranStockCancel.setSingleData(INBLOCK+"1", "mod_can_gubun", "4");			// 정정/취소 구분 4:전부취소, 3:일부취소
		
		m_tranStockCancel.setSingleData(INBLOCK+"1", "jong_code", strItemCode);				// 종목코드
		m_tranStockCancel.setSingleData(INBLOCK+"1", "jang_gubun", strItemType);				// 장내장외구분 0:코스피, 1:코스닥, 2:else
		m_tranStockCancel.setSingleData(INBLOCK+"1", "order_cnt", strOrderCount);			// 취소수량
		
		m_tranStockCancel.requestData();
	}

	private void requesetDailyPrice()
	{
		if(m_tranDailyPrice == null) return;

		m_arrListData.clear();

		String jangGubun = "11".equals(m_spinnerItemCode.getItemType()) ? "2" : "1";
		SimpleDateFormat formater = new SimpleDateFormat("yyyyMMdd", Locale.KOREA);
		Date current = new Date();
		String sDate = formater.format(current);

		//TR에 input값 세팅
		m_tranDailyPrice.setSingleData(INBLOCK+"1", "janggubun", jangGubun);
		m_tranDailyPrice.setSingleData(INBLOCK+"1", "jongcode", "000000"+m_spinnerItemCode.getItemCode());
		m_tranDailyPrice.setSingleData(INBLOCK+"1", "linkgb", "0");
		m_tranDailyPrice.setSingleData(INBLOCK+"1", "startdate", "0");
		m_tranDailyPrice.setSingleData(INBLOCK+"1", "enddate", sDate);
		m_tranDailyPrice.setSingleData(INBLOCK+"1", "readcount", "50");

		m_tranDailyPrice.requestData();
	}
	private void requestStockBalance()
	{
		if(m_tranStockBalance == null) return;

		m_arrBalanceListData.clear();

		m_tranStockBalance.clearInputData();
		m_tranStockBalance.clearOutputData();

		String strAccountNo = m_spinnerAccount.getAccountNo();
		String strAccountId = SmartNetMng.getInstance().getAccountInfo(strAccountNo, "accountid");



		//TR에 input값 세팅
		m_tranStockBalance.setSingleData(INBLOCK+"1", "kyejwa", strAccountNo);
		m_tranStockBalance.setSingleData(INBLOCK+"1", "acnt_aid", strAccountId);
		m_tranStockBalance.setSingleData(INBLOCK+"1", "jong_code", "");
		m_tranStockBalance.setSingleData(INBLOCK+"1", "gubun", "0");
		m_tranStockBalance.setSingleData(INBLOCK+"1", "sise_tp", "0");
		m_tranStockBalance.setSingleData(INBLOCK+"1", "entry_fee", "0"); // 매입가액수수료 ( 0:매매수수료 포함)
		m_tranStockBalance.setSingleData(INBLOCK+"1", "eval_fee", "9"); //평가손익 수수료 ( 9:매수매도수수료+제세금포함 )
		m_tranStockBalance.setSingleData(INBLOCK+"1", "add_loan", "0"); //신용합산여부 (0:분리조회 )
		m_tranStockBalance.setSingleData(INBLOCK+"1", "unlist_tp", "0");
		m_tranStockBalance.setSingleData(INBLOCK+"1", "tot_qty_ty", "0");

		m_tranStockBalance.requestData();
	}
	private void RequestStockChegyulReal()
	{
		// 조회 요청 전에, 실시간 요청을 먼저 클리어 한다
		if(m_realStockChegyul != null) m_realStockChegyul.cancelRealData();
		Log.e("hwannis", "RequestStockChegyulReal");
		m_realStockChegyul.requestReal();
	}
	private void RequestAccountChangeReal()
	{
		// 조회 요청 전에, 실시간 요청을 먼저 클리어 한다
		if(m_realAccountChange != null) m_realAccountChange.cancelRealData();
		m_realAccountChange.requestReal();
	}
	
	@Override
	public void onTranDataReceived(String sTranID, String sMsgCode, String sMsgText)
	{
		TRACE.d(LOG_TAG, String.format("onTranDataReceived [%s][%s][%s]", sTranID, sMsgCode, sMsgText));
		
		if(sTranID.equals("주식현재가"))
		{
			String strPrice = m_tranCurrPrice.getSingleData(OUTBLOCK+"1", "curjuka");
			int nPriceAttr = m_tranCurrPrice.getSingleDataAttr(OUTBLOCK+"1", "curjuka");
			String strDiff = m_tranCurrPrice.getSingleData(OUTBLOCK+"1", "debi");
			int nDiffAttr = m_tranCurrPrice.getSingleDataAttr(OUTBLOCK+"1","debi");
			String strDiffRatio = m_tranCurrPrice.getSingleData(OUTBLOCK+"1", "debirate");
			
			String strUpjong = m_tranCurrPrice.getSingleData(OUTBLOCK+"1", "upname");
			String strTradeAmount = m_tranCurrPrice.getSingleData(OUTBLOCK+"1", "volume");
			String strTradeMoney = m_tranCurrPrice.getSingleData(OUTBLOCK+"1", "money");
			
			m_viewItemPrice.setItemPrice(strPrice, nPriceAttr, strDiff, nDiffAttr, strDiffRatio);
			m_viewItemPrice.setTradeInfo(strTradeAmount, strTradeMoney);
			m_viewItemPrice.setItemInfo(strUpjong);
			
			requestCurrPriceReal();

		} else if(sTranID.equals("주식호가"))
		{
			// 5호가 데이터만 추출
			for(int nDataIndex = 0; nDataIndex < 5; nDataIndex++)
			{
				// 매도 호가
				String strMaedoHoga = m_tranCurrHoga.getMultiData(OUTBLOCK+"1", "medohoka", nDataIndex);
				int nMaedoHogaAttr = m_tranCurrHoga.getMultiDataAttr(OUTBLOCK+"1", "medohoka", nDataIndex);
				String strMaedoRemains = m_tranCurrHoga.getMultiData(OUTBLOCK+"1", "medovol", nDataIndex);
				
				// 매수호가
				String strMaesuHoga = m_tranCurrHoga.getMultiData(OUTBLOCK+"1", "mesuhoka", nDataIndex);
				int nMaesuHogaAttr = m_tranCurrHoga.getMultiDataAttr(OUTBLOCK+"1", "mesuhoka", nDataIndex);
				String strMaesuRemains = m_tranCurrHoga.getMultiData(OUTBLOCK+"1", "mesuvol", nDataIndex);
				
				m_viewItemHoga.setHoga(true, nDataIndex, strMaedoHoga, nMaedoHogaAttr, strMaedoRemains);
				m_viewItemHoga.setHoga(false, nDataIndex, strMaesuHoga, nMaesuHogaAttr, strMaesuRemains);
			}
			
			requestCurrHogaReal();
		} else if(sTranID.equals("주식매수주문"))
		{
			String strMessage = m_tranStockBuy.getSingleData(OUTBLOCK+"1", "msg");
			
			if(m_tranStockBuy.getDataMsgCode().equals("0"))
			{
				// 성공
				Toast.makeText(getContext(), strMessage, Toast.LENGTH_LONG).show();
			} else {
				Toast.makeText(getContext(), m_tranStockBuy.getDataMsgText(), Toast.LENGTH_LONG).show();
			}
		} else if(sTranID.equals("주식매도주문"))
		{
			String strMessage = m_tranStockSell.getSingleData(OUTBLOCK+"1", "msg");
			
			if(m_tranStockSell.getDataMsgCode().equals("0"))
			{
				// 성공
				Toast.makeText(getContext(), strMessage, Toast.LENGTH_LONG).show();
			} else {
				Toast.makeText(getContext(), m_tranStockSell.getDataMsgText(), Toast.LENGTH_LONG).show();
			}
		} else if(sTranID.equals("주식정정주문"))
		{
			String strMessage = m_tranStockModify.getSingleData(OUTBLOCK+"1", "msg");
			
			if(m_tranStockModify.getDataMsgCode().equals("0"))
			{
				// 성공
				Toast.makeText(getContext(), strMessage, Toast.LENGTH_LONG).show();
			} else {
				Toast.makeText(getContext(), m_tranStockModify.getDataMsgText(), Toast.LENGTH_LONG).show();
			}
		} else if(sTranID.equals("주식주문취소"))
		{
			String strMessage = m_tranStockCancel.getSingleData(OUTBLOCK+"1", "msg");
			
			if(m_tranStockCancel.getDataMsgCode().equals("0"))
			{
				// 성공
				Toast.makeText(getContext(), strMessage, Toast.LENGTH_LONG).show();
			} else {
				Toast.makeText(getContext(), m_tranStockCancel.getDataMsgText(), Toast.LENGTH_LONG).show();
			}
		} else if(sTranID.equals("일별주가"))
		{
			int nCount = m_tranDailyPrice.getDataCount(OUTBLOCK+"1");

			for (int i = 0; i < nCount; i++) {
				String date = m_tranDailyPrice.getMultiData(OUTBLOCK+"1", "basedate", i);
				String price = m_tranDailyPrice.getMultiData(OUTBLOCK+"1", "lastjuka", i);

				ListItem item = new ListItem();
				item.basedate = date;
				item.price = price;

				m_arrListData.add(item);
			}

            m_adapterDailyPrice.notifyDataSetChanged();

			if (m_tranDailyPrice.m_isMoreNextData) {
				m_btnNext.setEnabled(true);
			}
			else {
				m_btnNext.setEnabled(false);
			}
		} else if(sTranID.equals("보유잔고"))
		{
			int nCount = m_tranStockBalance.getDataCount(OUTBLOCK+"2");

			for (int i = 0; i < nCount; i++) {
				String stkName = m_tranStockBalance.getMultiData(OUTBLOCK+"2", "stk_name", i);
				String avgPrice = m_tranStockBalance.getMultiData(OUTBLOCK+"2", "jangbu_price", i);
				String curPrice = m_tranStockBalance.getMultiData(OUTBLOCK+"2", "curju_price", i);

				BalanceListItem item = new BalanceListItem();
				String[] arrStkNm = stkName.split("/");
				item.stkNm = arrStkNm[1];
				item.jangbu_price = avgPrice;
				item.curju_price = curPrice;

				m_arrBalanceListData.add(item);
			}

			m_adapterStockBalance.notifyDataSetChanged();

		}



	}
	
	@Override
	public void onTranTimeout(String sTranID)
	{
		// TODO Auto-generated method stub
		Log.e("onTranTimeout", String.format("TranId:%s ", sTranID));		
	}
	
	@Override
	public void onRealDataReceived(String strRealId)
	{
		if(strRealId.equals("주식현재가실시간"))
		{
			String strPrice = m_realCurrPrice.getRealData(OUTBLOCK+"1", "curjuka");
			int nPriceAttr = m_realCurrPrice.getRealDataAttr(OUTBLOCK+"1", "curjuka");
			String strDiff = m_realCurrPrice.getRealData(OUTBLOCK+"1", "debi");
			int nDiffAttr = m_realCurrPrice.getRealDataAttr(OUTBLOCK+"1", "debi");
			String strDiffRatio = m_realCurrPrice.getRealData(OUTBLOCK+"1", "debirate");
			
			String strTradeAmount = m_realCurrPrice.getRealData(OUTBLOCK+"1", "volume");
			String strTradeMoney = m_realCurrPrice.getRealData(OUTBLOCK+"1", "money");
			
			m_viewItemPrice.setItemPrice(strPrice, nPriceAttr, strDiff, nDiffAttr, strDiffRatio);
			m_viewItemPrice.setTradeInfo(strTradeAmount, strTradeMoney);
			
		} else if(strRealId.equals("주식호가실시간"))
		{
			// 5호가 데이터만 추출
			for(int nDataIndex = 0; nDataIndex < 5; nDataIndex++)
			{
				// 매도 호가
				String strMaedoHoga = m_realCurrHoga.getRealMultiData(OUTBLOCK+"2", "medohoka", nDataIndex);
				int nMaedoHogaAttr = m_realCurrHoga.getRealMultiDataAttr(OUTBLOCK+"2", "medohoka", nDataIndex);
				String strMaedoRemains = m_realCurrHoga.getRealMultiData(OUTBLOCK+"2", "medovol", nDataIndex);
				
				// 매수호가
				String strMaesuHoga = m_realCurrHoga.getRealMultiData(OUTBLOCK+"2", "mesuhoka", nDataIndex);
				int nMaesuHogaAttr = m_realCurrHoga.getRealMultiDataAttr(OUTBLOCK+"2", "mesuhoka", nDataIndex);
				String strMaesuRemains = m_realCurrHoga.getRealMultiData(OUTBLOCK+"2", "mesuvol", nDataIndex);
				
				m_viewItemHoga.setHoga(true, nDataIndex, strMaedoHoga, nMaedoHogaAttr, strMaedoRemains);
				m_viewItemHoga.setHoga(false, nDataIndex, strMaesuHoga, nMaesuHogaAttr, strMaesuRemains);
			}
		} else if(strRealId.equals("주식체결실시간"))
		{
			/**
			 *  == AUTO70 과 AUTO74 의 구분 ==
			 *  AUTO70 : 거래소에서 주식 체결이 된 시점의 TR
			 *  AUTO74 : 체결후, 유안타 서버에서 잔고변경 처리까지 완료시킨 시점의 TR
			 */

			String strgubun 	= m_realStockChegyul.getRealData(OUTBLOCK+"1","gubun48");
			Toast.makeText(m_actMain, "주식체결실시간 구분값: [" + strgubun + "]", Toast.LENGTH_LONG).show();

			/**
			 * 52:매수체결 53:차입체결 56:매도체결 57:대여체결 49:매수주문 50:매도주문 78:정정주문 74:매수정정주문 106:매도정정주문 77:매수정정확인 109:매도정정확인 71:매수정상확인 103:매도정상확인
			 * 68:취소주문 90:매수취소주문 122:매도취소주문 67:매수취소주문 99:매도취소확인 82:매수주문거부 114:매도주문거부 83:매수거부확인 115:매도거부확인 84:정정거부 116:취소거부
			 * 그외 코드 : 알수없음 처리
			 */
			if ("52".equals(strgubun) || "56".equals(strgubun) || "80".equals(strgubun) || "114".equals(strgubun) // 매수, 매도, 매수주문거부, 매도주문거부
					|| "83".equals(strgubun) || "115".equals(strgubun) || "84".equals(strgubun) || "116".equals(strgubun))	// 매수거부확인, 매도거부확인, 정정거부, 취소거부
			{
				// input source code

			}
			else
				return;

		} else if(strRealId.equals("잔고변경실시간"))
		{

			// input source code (ex. 계좌 잔고 재조회)
			String custseq	= m_realAccountChange.getRealData(OUTBLOCK+"1","custseq");
			Toast.makeText(m_actMain, "잔고변경 실시간:"+custseq, Toast.LENGTH_LONG).show();

			if( m_editAccountPwd != null && m_editAccountPwd.getText().toString() != "" ) {

				requestStockBalance();
			}
		}

	}

	@Override
	public void onClick(View view)
	{
		int nId = view.getId();
		
		if(nId == ID.CTRL_ID_BUY)
		{
			// 매수주문
			requestOrderBuy();
		} else if(nId == ID.CTRL_ID_SELL)
		{
			// 매도주문
			requestOrderSell();
		} else if(nId == ID.CTRL_ID_MODIFY)
		{
			// 정정주문
			requestOrderModify();
		} else if(nId == ID.CTRL_ID_CANCEL)
		{
			// 취소주문
			requestOrderCancel();
		} else if(nId == ID.CTRL_ID_NEXT)
		{
			if (m_tranDailyPrice != null && m_tranDailyPrice.m_isMoreNextData) {
				m_tranDailyPrice.requestNextData();
			}
		} else if(nId == ID.CTRL_ID_REFRESH)
		{
			refresh();
		}
	}

	class BalanceListItem
	{
		public String stkNm;
		public String jangbu_price;
		public String curju_price;
	}

	class StockBalanceAdapter extends BaseAdapter
	{
		private LayoutInflater inflater;
		private ArrayList<BalanceListItem> listAdapterItem;

		public StockBalanceAdapter(Context context, ArrayList<BalanceListItem> listAdapterItem) {
			inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
			this.listAdapterItem = listAdapterItem;
		}

		@Override
		public int getCount() {
			if(listAdapterItem == null) {
				return 0;
			}
			return listAdapterItem.size();
		}

		@Override
		public Object getItem(int position) {
			if(listAdapterItem == null) {
				return null;
			}
			return listAdapterItem.get(position);
		}

		@Override
		public long getItemId(int position) {
			return position;
		}

		@Override
		public View getView(final int position, View convertView, ViewGroup parent) {

			/* 현재 아이템 row 구성 객체 정보 */
			BalanceListItem item = listAdapterItem.get(position);
			LinearLayout layout = (LinearLayout)convertView;

			TextView textStkNm;
			TextView textJangbu;
			TextView textPrice;

			/* View의 재사용 여부 판단 */
			if (convertView == null) {
				layout = new LinearLayout(parent.getContext());
				layout.setOrientation(LinearLayout.HORIZONTAL);

				textStkNm = makeTextView("");
				textStkNm.setId(0);
				layout.addView(textStkNm, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(m_context, 25), 1));

				textJangbu = makeTextView("");
				textJangbu.setId(1);
				layout.addView(textJangbu, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(m_context, 25), 1));

				textPrice = makeTextView("");
				textPrice.setId(2);
				layout.addView(textPrice, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(m_context, 25), 1));
			}
			else {
				textStkNm = (TextView)layout.findViewById(0);
				textJangbu = (TextView)layout.findViewById(1);
				textPrice = (TextView)layout.findViewById(2);
			}

			textStkNm.setText(item.stkNm);
			textJangbu.setText(item.jangbu_price);
			textPrice.setText(item.curju_price);

			return layout;
		}
	}


	class ListItem
	{
		public String basedate;
		public String price;
	}

	class DailyPriceAdapter extends BaseAdapter
	{
		private LayoutInflater inflater;
		private ArrayList<ListItem> listAdapterItem;

		public DailyPriceAdapter(Context context, ArrayList<ListItem> listAdapterItem) {
			inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
			this.listAdapterItem = listAdapterItem;
		}

		@Override
		public int getCount() {
			if(listAdapterItem == null) {
				return 0;
			}
			return listAdapterItem.size();
		}

		@Override
		public Object getItem(int position) {
			if(listAdapterItem == null) {
				return null;
			}
			return listAdapterItem.get(position);
		}

		@Override
		public long getItemId(int position) {
			return position;
		}

		@Override
		public View getView(final int position, View convertView, ViewGroup parent) {

			/* 현재 아이템 row 구성 객체 정보 */
			ListItem item = listAdapterItem.get(position);
			LinearLayout layout = (LinearLayout)convertView;

			TextView textDate;
			TextView textPrice;

			/* View의 재사용 여부 판단 */
			if (convertView == null) {
                layout = new LinearLayout(parent.getContext());
                layout.setOrientation(LinearLayout.HORIZONTAL);

                textDate = makeTextView("");
                textDate.setId(0);
                layout.addView(textDate, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(m_context, 25), 1));

                textPrice = makeTextView("");
                textPrice.setId(1);
                layout.addView(textPrice, new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT, (int)SampleUtil.dipToPixels(m_context, 25), 1));
            }
            else {
			    textDate = (TextView)layout.findViewById(0);
			    textPrice = (TextView)layout.findViewById(1);
            }

            textDate.setText(item.basedate);
            textPrice.setText(item.price);

			return layout;
		}
	}
}
