package com.yuanta.smartnet.sample.view.util;

import java.text.DecimalFormat;

import android.content.Context;
import android.util.DisplayMetrics;
import android.util.TypedValue;
import android.widget.TextView;

public class SampleUtil
{
	public static DecimalFormat m_formatIntValue = new DecimalFormat("###,###,##0");
	public static DecimalFormat m_formatF2Value = new DecimalFormat("##0.00");
	public static DecimalFormat m_formatF4Value = new DecimalFormat("##0.0000");
	
	public static float dipToPixels(Context context, float dipValue)
	{
	    DisplayMetrics metrics = context.getResources().getDisplayMetrics();
	    return TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, dipValue, metrics);
	}
	
	public static int getIntValue(String strValue)
	{
		if(strValue == null) return 0;
		strValue = strValue.trim();
		if(strValue.isEmpty()) return 0;
		
		try {
			return Integer.parseInt(strValue);
		} catch(NumberFormatException exNF)
		{
		
		}
		
		return 0;
	}
	
	public static float getFloatValue(String strValue)
	{
		if(strValue == null) return 0f;
		strValue = strValue.trim();
		if(strValue.isEmpty()) return 0f;
		
		try {
			return Float.parseFloat(strValue);
		} catch(NumberFormatException exNF)
		{
		
		}
		
		return 0f;
	}

	public static void setIntValue(TextView view, String strValue)
	{
		setIntValue(view, strValue, 0, "", "");
	}

	public static void setIntValue(TextView view, String strValue, String strPrefix, String strPostfix)
	{
		setIntValue(view, strValue, 0, strPrefix, strPostfix);
	}

	public static void setIntValue(TextView view, String strValue, int nAttr)
	{
		setIntValue(view, strValue, nAttr, "", "");
	}

	public static void setIntValue(TextView view, String strValue, int nAttr, String strPrefix, String strPostfix)
	{
		int nValue = getIntValue(strValue);
		
		view.setText(strPrefix + m_formatIntValue.format(nValue) + strPostfix);
		view.setTextColor(getValueColor(nAttr));
	}
	
	public static void setF2Value(TextView view, String strValue, int nAttr)
	{
		setF2Value(view, strValue, nAttr, "", "");
	}
	
	public static void setF2Value(TextView view, String strValue, int nAttr, String strPrefix, String strPostfix)
	{
		float fValue = (float)Math.round(getFloatValue(strValue) * 100) / 100;
		
		view.setText(strPrefix + m_formatF2Value.format(fValue) + strPostfix);
		view.setTextColor(getValueColor(nAttr));
	}

	//소수점 4자리
	public static void setF4Value(TextView view, String strValue, int nAttr)
	{
		setF4Value(view, strValue, nAttr, "", "");
	}
	//소수점 4자리
	public static void setF4Value(TextView view, String strValue)
	{
		float fValue = (float)Math.round(getFloatValue(strValue) * 10000) / 10000;

		view.setText(m_formatF4Value.format(fValue) );
	}

	public static void setF4Value(TextView view, String strValue, int nAttr, String strPrefix, String strPostfix)
	{
		float fValue = (float)Math.round(getFloatValue(strValue) * 10000) / 10000;

		view.setText(strPrefix + m_formatF4Value.format(fValue) + strPostfix);
		view.setTextColor(getValueColor(nAttr));
	}
	
	public static void setSignValue(TextView view, int nAttr)
	{
		view.setText(getValueSign(nAttr));
		view.setTextColor(getValueColor(nAttr));
	}
	
	public static int getValueColor(int nAttr)
	{
		switch(nAttr)
		{
		case 0x01:	return ColorUtil.RISE;	// 상한
		case 0x02:	return ColorUtil.RISE;	// 상승 
		case 0x03:	return ColorUtil.STAY;	// 보합
		case 0x04:	return ColorUtil.FALL;		// 하한
		case 0x05:	return ColorUtil.FALL;	// 하락 
		
		// 유안타에 있는 속성인지 모름, 기존 소스가 이상함
		case 0x06:	return ColorUtil.RISE;	// 기세상한
		case 0x07:	return ColorUtil.RISE;	// 기세상승
		case 0x09:	return ColorUtil.FALL;	// 기세하한
		case 0x0A:	return ColorUtil.FALL;	// 기세하락
		}

		return ColorUtil.STAY;
	}
	
	public static String getValueSign(int nAttr)
	{
		switch(nAttr)
		{
		case 0x01:	return "↑";	// 상한
		case 0x02:	return "▲";	// 상승 
		case 0x03:	return "";	// 보합
		case 0x04:	return "↓";	// 하한
		case 0x05:	return "▼";	// 하락 
		
		// 유안타에 있는 속성인지 모름, 기존 소스가 이상함
		case 0x06:	return "↑↑";	// 기세상한
		case 0x07:	return "▲▲";	// 기세상승
		case 0x09:	return "↓↓";	// 기세하한
		case 0x0A:	return "▼▼";	// 기세하락
		}

		return "";
	}
}
